@@ -53,6 +53,7 @@
 gower_dist <- function(x, y, pair_x=NULL, pair_y=NULL, eps = 1e-8, weights=NULL,
                        ignore_case=FALSE, nthread=getOption("gd_num_thread")){
   check_recycling(nrow(x),nrow(y))
+  
   gower_work(x=x,y=y,pair_x=pair_x,pair_y=pair_y
     , n=NULL, eps=eps, weights=weights, ignore_case=ignore_case, nthread=nthread)
 }
@@ -94,6 +95,8 @@ gower_topn <- function(x, y, pair_x=NULL, pair_y = NULL, n=5, eps=1e-8, weights
 
 gower_work <- function(x, y, pair_x, pair_y, n, eps, weights, ignore_case, nthread){
   stopifnot(is.numeric(eps), eps>0) 
+
+  if (max(nrow(x), nrow(y)) <= 1000) nthread <- 1L
   
   if (is.null(pair_x) & is.null(pair_y)){
     xnames <- if(ignore_case) toupper(names(x)) else names(x)
@@ -141,7 +144,7 @@ gower_work <- function(x, y, pair_x, pair_y, n, eps, weights, ignore_case, nthre
   ranges <- numeric(length(pair))
   for ( i in seq_along(pair)){
     if (pair[i] == 0 ) next
-    ranges[i] <- .Call("R_get_xy_range",x[[i]],y[[pair[i]]],nthread)
+    ranges[i] <- .Call("R_get_xy_range",x[[i]],y[[pair[i]]],nthread,PACKAGE="gower")
   }
 
   factor_x <- sapply(x,is.factor)
@@ -176,10 +179,10 @@ gower_work <- function(x, y, pair_x, pair_y, n, eps, weights, ignore_case, nthre
   # translate to C-indices (base-0).
   pair <- as.integer(pair-1L)
   if (is.null(n)){
-    .Call("R_gower", x, y , ranges, pair, factor_pair, eps, weights, nthread)
+    .Call("R_gower", x, y , ranges, pair, factor_pair, eps, weights, nthread, PACKAGE="gower")
     
   } else {
-    L <- .Call("R_gower_topn", x, y, ranges, pair, factor_pair, as.integer(n), eps, weights, nthread)
+    L <- .Call("R_gower_topn", x, y, ranges, pair, factor_pair, as.integer(n), eps, weights, nthread, PACKAGE="gower")
     names(L) <- c("index","distance")
     dim(L$index) <- c(n,nrow(x))
     dim(L$distance) <- dim(L$index)
